@@ -5,7 +5,7 @@
 # - Each helper gets a reference to this command object.
 
 
-import sys, os, re, subprocess, logging
+import sys, os, platform, re, subprocess, logging
 from datetime import datetime
 from pathlib import Path
 
@@ -196,6 +196,13 @@ class Command(BaseCommand):
             msg = plsh_msgs.confirm_automate_all
         elif self.platform == 'fly_io':
             msg = flyio_msgs.confirm_automate_all
+        else:
+            # The platform name is not valid!
+            # DEV: This should be removed when the logic around when to call
+            #   _validate_platform() has been cleaned up.
+            # See issue #120: https://github.com/ehmatthes/django-simple-deploy/issues/120
+            error_msg = f"The platform {self.platform} is not currently supported."
+            raise CommandError(error_msg)
 
         self.write_output(msg, skip_logging=True)
         confirmed = self.get_confirmation(skip_logging=True)
@@ -292,16 +299,27 @@ class Command(BaseCommand):
 
 
     def _inspect_system(self):
-        """Find out if we're on Windows, so other methods can run system
-        commands appropriately on each system. Note this is the user's system,
-        not the host platform we're targeting.
+        """Inspect the user's local system for relevant information.
+
+        Currently, we only need to know whether we're on Windows or macOS. The
+          first need was just for Windows, which is why the variables are
+          self.on_windows rather than something more general like self.user_system.
+        Also, keep in mind that we can't use a name like self.platform, because
+          platform almost always has a different meaning in this project.
+
+        Some system-specific notes:
+        - Some CLI commands are os-specific.
+        - Some subsystem calls need to be made a specific way depending on the os.
         """
+        self.use_shell = False
+        self.on_windows, self.on_macos = False, False
         if os.name == 'nt':
+            # DEV: This should use platform.system() as well, but I'm not on Windows
+            #   at the moment, so can't test it properly.
             self.on_windows = True
             self.use_shell = True
-        else:
-            self.on_windows = False
-            self.use_shell = False
+        elif platform.system() == 'Darwin':
+            self.on_macos = True
 
 
     def _inspect_project(self):
@@ -639,7 +657,7 @@ class Command(BaseCommand):
         return output
 
 
-    def execute_command(self, cmd):
+    def execute_command(self, cmd, skip_logging=False):
         """Execute command, and stream output while logging.
         This method is intended for commands that run long enough that we 
         can't use a simple subprocess.run(capture_output=True), which doesn't
@@ -664,7 +682,7 @@ class Command(BaseCommand):
         with subprocess.Popen(cmd_parts, stderr=subprocess.PIPE,
             bufsize=1, universal_newlines=True, shell=self.use_shell) as p:
             for line in p.stderr:
-                self.write_output(line)
+                self.write_output(line, skip_logging=skip_logging)
 
         if p.returncode != 0:
             raise subprocess.CalledProcessError(p.returncode, p.args)
