@@ -37,6 +37,7 @@ class FlyioDeployer:
         self._set_debug()
 
         self._add_dockerfile()
+        self._add_dockerignore()
         self._add_flytoml_file()
         self._modify_settings()
 
@@ -132,6 +133,55 @@ class FlyioDeployer:
             return path
 
 
+    def _add_dockerignore(self):
+        """Add a dockerignore file, based on user's local project environmnet.
+        Ignore virtual environment dir, system-specific cruft, and IDE cruft.
+
+        If an existing dockerignore is found, make note of that but don't overwrite.
+
+        Returns:
+        - True if added dockerignore.
+        - False if dockerignore found unnecessary, or if an existing dockerfile
+          was found.
+        """
+
+        # Check for existing dockerignore file; we're only looking in project root.
+        #   If we find one, don't make any changes.
+        path = Path('.dockerignore')
+        if path.exists():
+            msg = "  Found existing .dockerignore file. Not overwriting this file."
+            self.sd.write_output(msg)
+            return
+
+        # Build dockerignore string.
+        dockerignore_str = ""
+
+        # Ignore git repository.
+        dockerignore_str += ".git/\n"
+
+        # Ignore venv dir if a venv is active.
+        venv_dir = os.environ.get("VIRTUAL_ENV")
+        if venv_dir:
+            venv_path = Path(venv_dir)
+            dockerignore_str += f"\n{venv_path.name}/\n"
+
+
+        # Add python cruft.
+        dockerignore_str += "\n__pycache__/\n*.pyc\n"
+
+        # Ignore any SQLite databases.
+        dockerignore_str += "\n*.sqlite3\n"
+
+        # If on macOS, add .DS_Store.
+        if self.sd.on_macos:
+            dockerignore_str += "\n.DS_Store\n"
+
+        # Write file.
+        path.write_text(dockerignore_str)
+        msg = "  Wrote .dockerignore file."
+        self.sd.write_output(msg)
+
+
     def _add_flytoml_file(self):
         """Add a minimal fly.toml file."""
         # File should be in project root, if present.
@@ -235,10 +285,10 @@ class FlyioDeployer:
         self.sd.commit_changes()
 
         # Push project.
+        # Use execute_command() to stream output of this long-running command.
         self.sd.write_output("  Deploying to Fly.io...")
         cmd = "fly deploy"
-        output = self.sd.execute_subp_run(cmd)
-        self.sd.write_output(output)
+        self.sd.execute_command(cmd)
 
         # Open project.
         self.sd.write_output("  Opening deployed app in a new browser tab...")
@@ -492,10 +542,9 @@ class FlyioDeployer:
         if not self.sd.automate_all:
             self._confirm_create_db(db_cmd=cmd)
 
-        # Create database and parse output.
-        output_obj = self.sd.execute_subp_run(cmd)
-        output_str = output_obj.stdout.decode()
-        self.sd.write_output(output_str, skip_logging=True)
+        # Create database.
+        # Use execute_command(), to stream output of long-running process.
+        self.sd.execute_command(cmd, skip_logging=True)
 
         msg = "  Created Postgres database."
         self.sd.write_output(msg, skip_logging=True)
